@@ -10,7 +10,7 @@ FBP::Window - Base class for all graphical wxWindow objects
 
 use Moose;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -67,6 +67,16 @@ has enabled => (
 	isa => 'Bool',
 );
 
+has pos => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has size => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 1;
 
 =pod
